==> was-plugin-5.0.1-sources.jar: com/xebialabs/deployit/plugin/was/contributor/StopStartCoreGroupContributor.java <==
package com.xebialabs.deployit.plugin.was.contributor;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

import com.xebialabs.deployit.plugin.api.deployment.planning.Contributor;
import com.xebialabs.deployit.plugin.api.deployment.planning.DeploymentPlanningContext;
import com.xebialabs.deployit.plugin.api.deployment.specification.Delta;
import com.xebialabs.deployit.plugin.api.deployment.specification.Deltas;
import com.xebialabs.deployit.plugin.api.reflect.Type;
import com.xebialabs.deployit.plugin.api.udm.Deployed;
import com.xebialabs.deployit.plugin.was.container.Cluster;
import com.xebialabs.deployit.plugin.was.container.ManagedServer;
import com.xebialabs.deployit.plugin.was.container.WasContainer;
import com.xebialabs.deployit.plugin.was.util.ContainerRestartStrategy;

import static com.google.common.collect.Sets.newHashSet;
import static com.google.common.collect.Sets.symmetricDifference;

public class StopStartCoreGroupContributor extends StopStartContainer {

    @Contributor
    public static void stopAndStartCoreGroupServers(Deltas deltas, DeploymentPlanningContext ctx) {
        StopStartCoreGroupContributor contributor = new StopStartCoreGroupContributor();
        contributor.doStopAndStartContainers(deltas, ctx);
    }

    @Override
    protected void findContainers(Deltas deltas, Set<WasContainer> stopStartContainers, Set<WasContainer> restartStartContainers) {
        for (Delta delta : deltas.getDeltas()) {
            final Set<WasContainer> previousContainers = findReferencedCoreGroupServers(delta.getPrevious());
            final Set<WasContainer> currentContainers = findReferencedCoreGroupServers(delta.getDeployed());

            stopStartContainers.addAll(symmetricDifference(previousContainers, currentContainers));
        }
    }

    private Set<WasContainer> findReferencedCoreGroupServers(final Deployed<?, ?> deployed) {
        HashSet<WasContainer> containers = newHashSet();
        if(!isApplicable(deployed)) {
            return containers;
        }

        Collection<ManagedServer> coreGroupServers = deployed.getProperty("coreGroupServers");
        if(coreGroupServers != null) {
            containers.addAll(coreGroupServers);
        }

        Collection<Cluster> coreGroupClusters = deployed.getProperty("coreGroupClusters");
        if(coreGroupClusters != null) {
            for (Cluster coreGroupCluster : coreGroupClusters) {
                containers.addAll(coreGroupCluster.getServers());
            }
        }

        return containers;
    }

    private boolean isApplicable(final Deployed<?, ?> deployed) {
        return deployed != null
                && deployed.getType().instanceOf(Type.valueOf("was.CoreGroup"))
                && deployed.hasProperty(CONTAINER_RESTART_STRATEGY)
                && deployed.getProperty(CONTAINER_RESTART_STRATEGY) != ContainerRestartStrategy.NONE;
    }
}

==> was-plugin-5.1.3-sources.jar: com/xebialabs/deployit/plugin/was/contributor/StopStartCoreGroupContributor.java <==
package com.xebialabs.deployit.plugin.was.contributor;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

import com.xebialabs.deployit.plugin.api.deployment.planning.Contributor;
import com.xebialabs.deployit.plugin.api.deployment.planning.DeploymentPlanningContext;
import com.xebialabs.deployit.plugin.api.deployment.specification.Delta;
import com.xebialabs.deployit.plugin.api.deployment.specification.Deltas;
import com.xebialabs.deployit.plugin.api.reflect.Type;
import com.xebialabs.deployit.plugin.api.udm.Deployed;
import com.xebialabs.deployit.plugin.was.container.Cluster;
import com.xebialabs.deployit.plugin.was.container.ManagedServer;
import com.xebialabs.deployit.plugin.was.container.WasContainer;
import com.xebialabs.deployit.plugin.was.util.ContainerRestartStrategy;

import static com.google.common.collect.Sets.newHashSet;
import static com.google.common.collect.Sets.symmetricDifference;

public class StopStartCoreGroupContributor extends StopStartContainer {

    @Contributor
    public static void stopAndStartCoreGroupServers(Deltas deltas, DeploymentPlanningContext ctx) {
        StopStartCoreGroupContributor contributor = new StopStartCoreGroupContributor();
        contributor.doStopAndStartContainers(deltas, ctx);
    }

    @Override
    protected void findContainers(Deltas deltas, Set<WasContainer> stopStartContainers, Set<WasContainer> restartStartContainers) {
        for (Delta delta : deltas.getDeltas()) {
            final Set<WasContainer> previousContainers = findReferencedCoreGroupServers(delta.getPrevious());
            final Set<WasContainer> currentContainers = findReferencedCoreGroupServers(delta.getDeployed());

           //RESTART strategy does not work with Core group deployment,  all the servers should be stopped before core group deployment so only STOP_START strategy can be used
            stopStartContainers.addAll(symmetricDifference(previousContainers, currentContainers));
        }
    }

    private Set<WasContainer> findReferencedCoreGroupServers(final Deployed<?, ?> deployed) {
        HashSet<WasContainer> containers = newHashSet();
        if(!isApplicable(deployed)) {
            return containers;
        }

        Collection<ManagedServer> coreGroupServers = deployed.getProperty("coreGroupServers");
        if(coreGroupServers != null) {
            containers.addAll(coreGroupServers);
        }

        Collection<Cluster> coreGroupClusters = deployed.getProperty("coreGroupClusters");
        if(coreGroupClusters != null) {
            for (Cluster coreGroupCluster : coreGroupClusters) {
                containers.addAll(coreGroupCluster.getServers());
            }
        }

        return containers;
    }

    private boolean isApplicable(final Deployed<?, ?> deployed) {
        return deployed != null
                && deployed.getType().instanceOf(Type.valueOf("was.CoreGroup"))
                && deployed.hasProperty(CONTAINER_RESTART_STRATEGY)
                && deployed.getProperty(CONTAINER_RESTART_STRATEGY) != ContainerRestartStrategy.NONE;
    }
}
